<?php
/**
 * Plugin Name: WordPress Smart SEO
 * Plugin URI: https://dedidata.com/smart-seo
 * Description: This plugin optimizes WordPress for better ranking in Google and other Search Engines
 * Version: 1.0.0
 * Author: DediData
 * Author URI: https://dedidata.com
 * Requires at least: 4.4
 * Tested up to: 5.2.3
 *
 * Text Domain: wpseo
 * Domain Path: /languages/
 */

defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

/**
 * Class WPSEO
 */
class WPSEO {

	/**
	 * @var
	 */
	protected $plugin_name;
	/**
	 * @var
	 */
	protected $plugin_slug;
	/**
	 * @var
	 */
	protected $plugin_url;
	/**
	 * @var
	 */
	protected $plugin_version;

	/**
	 * Constructor.
	 */
	function __construct(){
		$this->set_plugin_info();
		register_activation_hook(__FILE__,		[ $this, 'activate' ]);
		register_deactivation_hook(__FILE__,	[ $this, 'deactivate' ]);
		register_uninstall_hook(__FILE__, __CLASS__ . '::uninstall');
		add_action('plugins_loaded',						[ $this, 'load_languages' ]);
		spl_autoload_register(							[ $this, 'autoloader' ]);
		add_action('wp_enqueue_scripts', 			[ $this, 'load_frontend_scripts' ], 11);
		if ( is_admin() ) {
			add_action('admin_enqueue_scripts', [ $this, 'load_admin_scripts' ], 110000000);
			$this->admin();
		} else {
			$this->run();
		}
	}

	/**
	 *
	 */
	function set_plugin_info(){
		$this->plugin_slug 		= basename(__FILE__, '.php');
		$this->plugin_url  		= plugins_url(null, __FILE__);
		if ( ! function_exists('get_plugins') ){
			require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		}
		$plugin_folder				= get_plugins('/' . plugin_basename(dirname(__FILE__)));
		$plugin_file					= basename(( __FILE__ ));
		$this->plugin_version	= $plugin_folder[ $plugin_file ]['Version'];
		$this->plugin_name		= $plugin_folder[ $plugin_file ]['Name'];
	}

	/**
	 *
	 */
	function activate() {

	}

	/**
	 *
	 */
	function deactivate() {

	}

	/**
	 *
	 */
	static function uninstall() {
		delete_option('WPSEO');
	}

	/**
	 *
	 */
	function load_languages(){
		load_plugin_textdomain($this->plugin_slug, false, dirname(plugin_basename(__FILE__)) . '/languages/');
	}

	/**
	 * @param $class
	 */
	function autoloader( $class ){
		$class_file = realpath(dirname(__FILE__) . '/inc/classes/' . $class . '.php');
		if ( file_exists($class_file) ) {
			include( $class_file );
		}
	}

	/**
	 *
	 */
	function load_frontend_scripts(){

	}

	// Styles for Admin
	/**
	 *
	 */
	function load_admin_scripts(){

	}

	/**
	 *
	 */
	function admin() {
		//include( plugin_dir_path(__FILE__) . 'options.php' );
		//add_action('admin_menu', [$this, 'register_wpseo_menu']);
	}
	
	/**
	* Register a custom menu page.
	*/
	function register_wpseo_menu() {

	}
	
	/**
	 *
	 */
	function run() {
		add_action( 'wp_head', [$this, 'add_meta_description']);
	}
	
	
	
	public function add_meta_description() {
		global $post;
		
		if ( is_front_page() ){
			$content = $this->prepare_description_content( get_bloginfo('name') . ' - ' . get_bloginfo('description') . ' - ' . $post->post_content);
		}elseif( is_archive() ){
			if( is_paged() ){
				$page_content = ' - ' . esc_html__('Page:') . get_query_var( 'paged' );
			}else{
				$page_content = '';
			}
			if ( ! empty( get_the_archive_description() ) ){
				$content = $this->prepare_description_content( get_the_archive_description() . $page_content );
			}else{
				$content = $this->prepare_description_content( wp_title( '', false ) . $page_content );
			}
		}elseif ( has_excerpt() ) {
			// Return the excerpt() if it exists other truncate.
			$content = $this->prepare_description_content( $post->post_excerpt );
		} elseif ( ! empty( $post->post_content ) ) {
			$content = $this->prepare_description_content( $post->post_content );
		}
		
		if ( empty($content) ){
			$content = $this->prepare_description_content( wp_title( '', false ) );
		}


		echo '<meta name="description" content="' . esc_attr( strip_tags( stripslashes( $content ) ) ) . '" />' . PHP_EOL;
	}
	
	public function prepare_description_content($content){
		return strip_shortcodes( wp_trim_words( $content, 35, '...' ) );
	}
	
}

new WPSEO;
